@@ -2,7 +2,7 @@
 #
 # barriosqdata.py - barrioSquare data access layer
 # 
-# barrioSquare v0.3.4
+# barrioSquare v0.3.5
 # Copyright(c) 2010 Chili Technologies LLC
 # http://www.chilitechno.com/fster
 #
@@ -32,7 +32,7 @@
 # ============================================================================
 # Name        : barriodata.py
 # Author      : Chris J. Burris - chris@chilitechno.com
-# Version     : 0.3.4
+# Version     : 0.3.5
 # Description : barrioSquare
 # ============================================================================
 
@@ -40,9 +40,11 @@ import os
 import shutil
 import datetime
 import string
-
+import barriotime
 from PyQt4 import QtCore, QtSql
 
+import re
+
 class DataWorker(QtCore.QObject):
 	def __init__(self, db):
 		QtCore.QObject.__init__(self)
@@ -462,7 +464,7 @@ class DataManager(QtCore.QObject):
 		# build the query
 		strNow = datetime.datetime.utcnow()
 		# convert the created date to database friendly
-		createdDate = str(datetime.datetime.strptime(createdDateStr,'%a, %d %b %y %H:%M:%S +0000'))
+		createdDate = str(barriotime.fsq_date_to_dt(createdDateStr))
 
 		queryParams = { }
 
